==> haskell-prelude-extras-0.4.0.3-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prelude-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prelude-extras
version:              0.4.0.3
visibility:           public
id:                   prelude-extras-0.4.0.3-K2GAI961UOh9OzBleXkSQi
key:                  prelude-extras-0.4.0.3-K2GAI961UOh9OzBleXkSQi
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/prelude-extras
synopsis:             Higher order versions of Prelude classes
description:
    Higher order versions of Prelude classes to ease programming with polymorphic recursion and reduce UndecidableInstances

    See <http://flint.cs.yale.edu/trifonov/papers/sqcc.pdf> for further discussion of the approach taken here.

category:             Polymorphism, Combinators
abi:                  157da08db023d82945fa22d12a11f141
exposed:              True
exposed-modules:      Prelude.Extras
import-dirs:          /usr/lib/ghc-9.0.1/site-local/prelude-extras-0.4.0.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/prelude-extras-0.4.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/prelude-extras-0.4.0.3
hs-libraries:         HSprelude-extras-0.4.0.3-K2GAI961UOh9OzBleXkSQi
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-prelude-extras/html/prelude-extras.haddock

haddock-html:         /usr/share/doc/haskell-prelude-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prelude-extras-0.4.0.3-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prelude-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prelude-extras
version:              0.4.0.3
visibility:           public
id:                   prelude-extras-0.4.0.3-LaPNLqCLn3UDyZWYo4yDP1
key:                  prelude-extras-0.4.0.3-LaPNLqCLn3UDyZWYo4yDP1
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/prelude-extras
synopsis:             Higher order versions of Prelude classes
description:
    Higher order versions of Prelude classes to ease programming with polymorphic recursion and reduce UndecidableInstances

    See <http://flint.cs.yale.edu/trifonov/papers/sqcc.pdf> for further discussion of the approach taken here.

category:             Polymorphism, Combinators
abi:                  dfaa278418d29d4d1f3333151d72c3e5
exposed:              True
exposed-modules:      Prelude.Extras
import-dirs:          /usr/lib/ghc-9.0.2/site-local/prelude-extras-0.4.0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/prelude-extras-0.4.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/prelude-extras-0.4.0.3
hs-libraries:         HSprelude-extras-0.4.0.3-LaPNLqCLn3UDyZWYo4yDP1
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-prelude-extras/html/prelude-extras.haddock

haddock-html:         /usr/share/doc/haskell-prelude-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
